import { select, transition, easeLinear } from 'd3';
import data from './data.csv';
import './styles.css';

export const main = (container) => {
  const svg = select(container)
    .selectAll('svg')
    .data([1])
    .join('svg')
    .attr('width', container.clientWidth)
    .attr('height', container.clientHeight)
    .style('background-color', '#F0FFF2');

  const slow = transition().duration(2000);
  const fast = transition().duration(200).ease(easeLinear);
  //make s10 squares
const squares = svg
    .selectAll('rect')
    .data(Array(10).fill(), (d, i) => i)
    .join('rect')
    .attr('width', 20)
    .attr('height', 20)
    .attr('x', (d, i) => i * 25)
    .attr('y', 50)
    .attr('fill', 'blue');
  

  svg
    .selectAll('circle')
    .data(data, (d) => d.id)
    .join(
      (enter) =>
        enter
          .append('circle')
          .attr('r', 0)
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
          .attr('fill', (d) => d.fill)
          .call((selection) => {
            selection
              .transition(slow)
              .delay((d, i) => i * 200)
              .attr('r', (d) => d.r);
          }),
      (update) =>
        update.call((selection) => {
          selection
            .transition(fast)
            .attr('cx', (d) => d.x)
            .attr('cy', (d) => d.y)
            .attr('r', (d) => d.r)
            .attr('fill', (d) => d.fill);
        }),
      (exit) =>
        exit.call((selection) =>
          selection.transition(slow).attr('r', 0).remove(),
        ),
    )
    .attr('opacity', 880 / 1000);
};
